###############################################################################################################################
###############################################################################################################################
###############################################################################################################################

        # Python script for Figures in following paper (c) by W. Yao, L. Puts, K. Williams and D. Lenstra
        # as part of the work published in "An All-Optical Spiking Laser Neuron Integrated in Generic 
        # InP Photonic Circuit Technology" published in Optics Express
        # 
        # This work is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
        # 
        # You should have received a copy of the license along with this work. If not, see 
        # <https://creativecommons.org/licenses/by-nc-sa/4.0/>.
        
        # Eindhoven Univesity of Technology, Eindhoven, the Netherlands, May 2025
        
        # Contact: l.puts@tue.nl

###############################################################################################################################
###############################################################################################################################
###############################################################################################################################

import numpy as np
import matplotlib.pyplot as plt

plt.rcParams["font.family"] = 'Times New Roman'
plt.rcParams['font.size'] = 12

file_inject='Injected light I 51.750 V -1.200 2024-08-14_13_53_35.npy'
file_output='Output light I 51.750 V -1.200 2024-08-14_13_53_35.npy'

inject=np.load(file_inject)
output=np.load(file_output)

plt.close('all')
fig, axs = plt.subplots(2,figsize=(4, 3))
fig.patch.set_alpha(0)
axs[0].plot(inject[0]*1e9-2.3,inject[1],'k',linewidth=0.7)
axs[1].plot(inject[0]*1e9,output[1],'k',linewidth=1.0)
axs[0].set_ylabel('Inj. signal [V]', fontsize=10)
axs[1].set_ylabel('Exc. signal [V]', fontsize=10)
axs[1].set_xlabel('Time [ns]', fontsize=10)
axs[0].set_xlim([0,50])
axs[1].set_xlim([0,50])
axs[0].set_ylim([-0.002,0.012])
axs[0].annotate('1544.77 nm',xy=(2.97,0.00473),xytext=(2.97,0.00873), va = "bottom", ha="left",arrowprops=dict(arrowstyle='->',lw=1.5),fontsize=10)
axs[0].annotate('1546.11 nm',xy=(6.2,0.00473),xytext=(9.97,0.006), va = "bottom", ha="left",arrowprops=dict(arrowstyle='->',lw=1.5),fontsize=10)
plt.tight_layout()
